@@ -49,6 +49,9 @@ re_unhtmlsub = re_unhtml.sub
 # imdb person or movie ids.
 re_imdbID = re.compile(r'(?<=nm|tt|ch)([0-9]{7})\b')
 
+# movie AKAs.
+re_makas = re.compile('(<p class="find-aka">.*?</p>)')
+
 
 def _unHtml(s):
     """Return a string without tags and no multiple spaces."""
@@ -127,6 +130,8 @@ class IMDbMobileAccessSystem(IMDbHTTPAccessSystem):
     def _clean_html(self, html):
         """Normalize the retrieve html."""
         html = re_spaces.sub(' ', html)
+        # Remove silly &nbsp;&raquo; chars.
+        html = html.replace('&nbsp;&raquo;', '')
         return subXMLRefs(html)
 
     def _mretrieve(self, url, size=-1):
@@ -206,20 +211,17 @@ class IMDbMobileAccessSystem(IMDbHTTPAccessSystem):
             lis = _findBetween(cont, 'td valign="top">', '</td>',
                                 maxRes=results*3)
             for li in lis:
-                akaIdx = li.find('aka <em>')
-                akas = []
-                if akaIdx != -1:
-                    akas = [_unHtml(x) for x in li[akaIdx:].split('<br>')]
-                    li = li[:akaIdx]
-                if akas:
-                    for idx, aka in enumerate(akas):
-                        aka = aka.replace('" - ', '::')
-                        if aka.startswith('aka "'):
-                            aka = aka[5:]
-                        if aka[-1] == '"':
-                            aka = aka[:-1]
-                        akas[idx] = aka
+                akas = re_makas.findall(li)
+                for idx, aka in enumerate(akas):
+                    aka = aka.replace('" - ', '::', 1)
+                    aka = _unHtml(aka)
+                    if aka.startswith('aka "'):
+                        aka = aka[5:].strip()
+                    if aka[-1] == '"':
+                        aka = aka[:-1]
+                    akas[idx] = aka
                 imdbid = re_imdbID.findall(li)
+                li = re_makas.sub('', li)
                 mtitle = _unHtml(li)
                 if not (imdbid and mtitle):
                     self._mobile_logger.debug('no title/movieID parsing' \
@@ -393,9 +395,12 @@ class IMDbMobileAccessSystem(IMDbHTTPAccessSystem):
         if akas:
             # For some reason, here <br> is still used in place of <br/>.
             akas[:] = [x for x in akas[0].split('<br>') if x.strip()]
-            akas = [_unHtml(x).replace(' (','::(', 1) for x in akas]
-            if 'more' in akas: akas.remove('more')
-            d['akas'] = akas
+            akas = [_unHtml(x).replace('" - ','::', 1).lstrip('"').strip()
+                    for x in akas]
+            if 'See more' in akas: akas.remove('See more')
+            akas[:] = [x for x in akas if x]
+            if akas:
+                d['akas'] = akas
         mpaa = _findBetween(cont, 'MPAA</a>:', '</div>', maxRes=1)
         if mpaa: d['mpaa'] = _unHtml(mpaa[0])
         runtimes = _findBetween(cont, 'Runtime:</h5>', '</div>', maxRes=1)
@@ -428,13 +433,14 @@ class IMDbMobileAccessSystem(IMDbHTTPAccessSystem):
             lang[:] = ['<a %s' % x for x in lang if x]
             lang[:] = [_unHtml(x.replace(' <i>', '::')) for x in lang]
             if lang: d['languages'] = lang
-        col = _findBetween(cont, '"/List?color-info=', '</div>')
+        col = _findBetween(cont, '"/search/title?colors=', '</div>')
         if col:
             col[:] = col[0].split(' | ')
             col[:] = ['<a %s' % x for x in col if x]
             col[:] = [_unHtml(x.replace(' <i>', '::')) for x in col]
             if col: d['color info'] = col
-        sm = _findBetween(cont, '/List?sound-mix=', '</div>', maxRes=1)
+        sm = _findBetween(cont, '/search/title?sound_mixes=', '</div>',
+                            maxRes=1)
         if sm:
             sm[:] = sm[0].split(' | ')
             sm[:] = ['<a %s' % x for x in sm if x]
@@ -470,8 +476,6 @@ class IMDbMobileAccessSystem(IMDbHTTPAccessSystem):
                 plot[i] = '%s::%s' % \
                         (p[:wbyidx].rstrip(),
                     p[wbyidx+12:].rstrip().replace('{','<').replace('}','>'))
-            else:
-                plot[i] = '%s::Anonymous' % p
         if plot: return {'data': {'plot': plot}}
         return {'data': {}}
 
